@@ -6,6 +6,9 @@ context("powell_wiley")
 
 test_that("powell_wiley throws error with invalid arguments", {
   
+  # Not a data.frame or tibble for `df`
+  expect_error(powell_wiley(df = c("a", "b", "c")))
+  
   # Unavailable geography
   expect_error(powell_wiley(geo = "zcta", state = "DC", year = 2020, quiet = TRUE))
   
@@ -25,10 +28,14 @@ test_that("powell_wiley throws error with invalid arguments", {
 
 test_that("powell_wiley works", {  
   
+  expect_message(powell_wiley(df = DCtracts2020[ , -c(3:10)]))
+  
   skip_if(Sys.getenv("CENSUS_API_KEY") == "")
   
   expect_message(powell_wiley(state = "DC", year = 2020))
   
+  expect_message(powell_wiley(state = "DC", year = 2020, round_output = TRUE))
+  
   expect_message(powell_wiley(state = "DC", year = 2020, imp = TRUE))
   
   expect_silent(powell_wiley(state = "DC", year = 2020, quiet = TRUE))
